searchData={"items":[{"type":"module","title":"Prometheus","doc":"[Prometheus.io](https://prometheus.io) client library powered by\n[prometheus.erl](https://hexdocs.pm/prometheus)\n\nPrometheus.ex is a thin, mostly macro-based wrapper around prometheus.erl.\nWhile it's pretty straightforward to use prometheus.erl from Elixir,\nyou might prefer prometheus.ex because it gives you:\n\n - native Elixir syntax;\n - native Elixir exceptions;\n - configuration helpers that are really handy if you plan to write your custom\n instrumenter.\n\n```elixir\ndefmodule ExampleInstrumenter do\n  use Prometheus","ref":"Prometheus.html"},{"type":"module","title":"require common Prometheus modules, also alias metrics. - Prometheus","doc":"def setup do\n    Histogram.new([name: :http_request_duration_milliseconds,\n                   labels: [:method],\n                   buckets: [100, 300, 500, 750, 1000],\n                   help: \"Http Request execution time\"])\n  end\n\n  def instrument(%{time: time, method: method}) do\n    Histogram.observe([name: :http_request_duration_milliseconds,\n                       labels: [method]],\n                      time)\n  end\nend\n\n```","ref":"Prometheus.html#module-require-common-prometheus-modules-also-alias-metrics"},{"type":"module","title":"Integrations - Prometheus","doc":"- [Ecto Instrumenter](https://hex.pm/packages/prometheus_ecto);\n - [Elixir plugs Instrumenters and Exporter](https://hex.pm/packages/prometheus_plugs);\n - [Fuse plugin](https://github.com/jlouis/fuse#fuse_stats_prometheus)\n - [OS process info Collector](https://hex.pm/packages/prometheus_process_collector)\n (Linux-only);\n - [Phoenix Instrumenter](https://hex.pm/packages/prometheus_phoenix);\n - [RabbitMQ Exporter](https://github.com/deadtrickster/prometheus_rabbitmq_exporter).","ref":"Prometheus.html#module-integrations"},{"type":"module","title":"Erlang VM Collectors - Prometheus","doc":"- [Memory Collector](vm-memory-collector.html);\n - [Statistics Collector](vm-statistics-collector.html);\n - [System Information Collector](vm-system-info-collector.html).","ref":"Prometheus.html#module-erlang-vm-collectors"},{"type":"module","title":"API - Prometheus","doc":"API can be grouped like this:","ref":"Prometheus.html#module-api"},{"type":"module","title":"Standard Metrics & Registry - Prometheus","doc":"- `Prometheus.Metric.Counter` - counter metric, to track counts of events or running\n totals;\n - `Prometheus.Metric.Gauge` - gauge metric, to report instantaneous values;\n - `Prometheus.Metric.Histogram` - histogram metric, to track distributions of events;\n - `Prometheus.Metric.Summary` - summary metric, to track the size of events;\n - `Prometheus.Registry` - working with Prometheus registries.\n\nAll metrics created via `new/1` or `declare/1` macros. The difference is that `new/1`\nactually wants metric to be new and raises `Prometheus.MFAlreadyExistsError`\nif it isn't.\n\nBoth `new/1` and `declare/1` accept options as\n[Keyword](https://hexdocs.pm/elixir/Keyword.html).\nCommon options are:\n\n - name - metric name, can be an atom or a string (required);\n - help - metric help, string (required);\n - labels - metric labels, label can be an atom or a string (default is []);\n - registry - Prometheus registry for the metric, can be any term. (default is :default)\n\nHistogram also accepts `buckets` option. Please refer to respective modules docs\nfor the more information.","ref":"Prometheus.html#module-standard-metrics-registry"},{"type":"module","title":"General Helpers - Prometheus","doc":"- `Prometheus.Buckets` - linear or exponential bucket generators;\n - `Prometheus.Contrib.HTTP` - helpers for HTTP instrumenters.","ref":"Prometheus.html#module-general-helpers"},{"type":"module","title":"Integration Helpers - Prometheus","doc":"- `Prometheus.Config` - provides standard configuration mechanism\n for custom instrumenters/exporters.","ref":"Prometheus.html#module-integration-helpers"},{"type":"module","title":"Exposition Formats - Prometheus","doc":"- `Prometheus.Format.Text` - renders metrics for a given registry\n (default is `:default`) in text format;\n - `Prometheus.Format.Protobuf` - renders metrics for a given registry\n (default is `:default`) in protobuf v2 format.","ref":"Prometheus.html#module-exposition-formats"},{"type":"module","title":"Advanced - Prometheus","doc":"You will need this modules only if you're writing custom collector for app/lib\nthat can't be instrumented directly.\n\n - `Prometheus.Collector` - exports macros for managing/creating collectors;\n - `Prometheus.Model` - provides API for working with underlying Prometheus models.\n You'll use that if you want to create custom collector.","ref":"Prometheus.html#module-advanced"},{"type":"module","title":"Prometheus.Buckets","doc":"Histogram buckets generators.","ref":"Prometheus.Buckets.html"},{"type":"function","title":"Prometheus.Buckets.new/1","doc":"iex(2)> Prometheus.Buckets.new(:default)\n    [0.005, 0.01, 0.025, 0.05, 0.1, 0.25, 0.5, 1, 2.5, 5, 10, :infinity]  \n\n    iex(3)> Prometheus.Buckets.new({:exponential, 100, 1.2, 3})\n    [100, 120, 144, :infinity]  \n\n    iex(2)> Prometheus.Buckets.new({:linear, 10, 5, 6})\n    [10, 15, 20, 25, 30, 35, :infinity]","ref":"Prometheus.Buckets.html#new/1"},{"type":"module","title":"Prometheus.Collector","doc":"A collector for a set of metrics.\n\nNormal users should use `Prometheus.Metric.Gauge`, `Prometheus.Metric.Counter`,\n`Prometheus.Metric.Summary`\nand `Prometheus.Metric.Histogram`.\n\nImplementing `:prometheus_collector` behaviour is for advanced uses such as proxying\nmetrics from another monitoring system.\nIt is the responsibility of the implementer to ensure produced metrics are valid.\n\nYou will be working with Prometheus data model directly (see `Prometheus.Model` ).\n\nCallbacks:\n- `collect_mf(registry, callback)` - called by exporters and formats.\nShould call `callback` for each `MetricFamily` of this collector;\n- `collect_metrics(name, data)` - called by `MetricFamily` constructor.\nShould return Metric list for each MetricFamily identified by `name`.\n`data` is a term associated with MetricFamily by collect_mf.\n- `deregister_cleanup(registry)` - called when collector unregistered by\n`registry`. If collector is stateful you can put cleanup code here.\n\nExample (simplified [`:prometheus_vm_memory_collector`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_vm_memory_collector.md)):\n\n```\niex(3)> defmodule Prometheus.VMMemoryCollector do\n...(3)>   use Prometheus.Collector\n...(3)>\n...(3)>   @labels [:processes, :atom, :binary, :code, :ets]\n...(3)>\n...(3)>   def collect_mf(_registry, callback) do\n...(3)>     memory = :erlang.memory()\n...(3)>     callback.(create_gauge(\n...(3)>           :erlang_vm_bytes_total,\n...(3)>           \"The total amount of memory currently allocated.\",\n...(3)>           memory))\n...(3)>     :ok\n...(3)>   end\n...(3)>\n...(3)>   def collect_metrics(:erlang_vm_bytes_total, memory) do\n...(3)>     Prometheus.Model.gauge_metrics(\n...(3)>       for label <- @labels do\n...(3)>         {[type: label], memory[label]}\n...(3)>       end)\n...(3)>   end\n...(3)>\n...(3)>   defp create_gauge(name, help, data) do\n...(3)>     Prometheus.Model.create_mf(name, help, :gauge, __MODULE__, data)\n...(3)>   end\n...(3)> end\niex(4)> Prometheus.Registry.register_collector(Prometheus.VMMemoryCollector)\n:ok\niex(5)> r = ~r/# TYPE erlang_vm_bytes_total gauge\n...(5)> # HELP erlang_vm_bytes_total\n...(5)> The total amount of memory currently allocated.\n...(5)> erlang_vm_bytes_total{type=\"processes\"} [1-9]\n...(5)> erlang_vm_bytes_total{type=\"atom\"} [1-9]\n...(5)> erlang_vm_bytes_total{type=\"binary\"} [1-9]\n...(5)> erlang_vm_bytes_total{type=\"code\"} [1-9]\n...(5)> erlang_vm_bytes_total{type=\"ets\"} [1-9]/\niex(6)> Regex.match?(r, Prometheus.Format.Text.format)\ntrue\n```","ref":"Prometheus.Collector.html"},{"type":"function","title":"Prometheus.Collector.collect_mf/3","doc":"Calls `callback` for each MetricFamily of this collector.","ref":"Prometheus.Collector.html#collect_mf/3"},{"type":"module","title":"Prometheus.Config","doc":"Configuration templates for custom collectors/exporters.\n\nWhen `use`ed, generates accessor for each configuration option:\n\n    iex(4)> defmodule MyInstrumenter do\n    ...(4)>   use Prometheus.Config, [:required_option,\n    ...(4)>                           registry: :default]\n    ...(4)> end\n    iex(5)> MyInstrumenter.Config.registry(MyInstrumenter)\n    :default\n    iex(6)> MyInstrumenter.Config.required_option!(MyInstrumenter)\n    ** (Prometheus.Config.KeyNotFoundError) mandatory option :required_option not found in PrometheusTest.MyInstrumenter instrumenter/collector config\n    iex(7)> Application.put_env(:prometheus, MyInstrumenter,\n    ...(7)>                     [required_option: \"Hello world!\"])\n    :ok\n    iex(8)> MyInstrumenter.Config.required_option!(MyInstrumenter)\n    \"Hello world!\"","ref":"Prometheus.Config.html"},{"type":"module","title":"Prometheus.Contrib.HTTP","doc":"HTTP instrumentation helpers","ref":"Prometheus.Contrib.HTTP.html"},{"type":"macro","title":"Prometheus.Contrib.HTTP.microseconds_duration_buckets/0","doc":"Returns default microseconds buckets for measuring http requests duration:\n\n    iex(6)> Prometheus.Contrib.HTTP.microseconds_duration_buckets\n    [10, 25, 50, 100, 250, 500, 1000, 2500, 5000, 10000, 25000, 50000,\n     100000, 250000, 500000, 1000000, 2500000, 5000000, 10000000]","ref":"Prometheus.Contrib.HTTP.html#microseconds_duration_buckets/0"},{"type":"macro","title":"Prometheus.Contrib.HTTP.status_class/1","doc":"Returns class of the http status code:\n\n    iex(7)> Prometheus.Contrib.HTTP.status_class(202)\n    ~c\"success\"\n\nRaises `Prometheus.InvalidValueError` exception if `code` is not a positive integer.","ref":"Prometheus.Contrib.HTTP.html#status_class/1"},{"type":"module","title":"Prometheus.Contrib.Mnesia","doc":"Mnesia instrumentation helpers.","ref":"Prometheus.Contrib.Mnesia.html"},{"type":"function","title":"Prometheus.Contrib.Mnesia.table_disk_size/2","doc":"Returns sum of all mnesia files for the given `table` in bytes.\nMnesia can create different files for each table:\n- .DAT - DETS files\n- .TMP - temp files\n- .DMP - dumped ets tables\n- .DCD - disc copies data\n- .DCL - disc copies log\n- .LOGTMP - disc copies log\n\nMore on Mnesia files can be found in\n \nMnesia System Information chapter\n  of Mnesia User's Guide","ref":"Prometheus.Contrib.Mnesia.html#table_disk_size/2"},{"type":"function","title":"Prometheus.Contrib.Mnesia.tm_info/0","doc":"Returns {pcount, ccount} tuple, where\npcount is a number of participant transactions and\nccount is a number of coordinator transactions.\nCan return {:undefined, :undefined} occasionally.","ref":"Prometheus.Contrib.Mnesia.html#tm_info/0"},{"type":"module","title":"Prometheus.Format.Protobuf","doc":"Serializes Prometheus registry using [protocol buffer format](http://bit.ly/2cxSuJP).","ref":"Prometheus.Format.Protobuf.html"},{"type":"function","title":"Prometheus.Format.Protobuf.content_type/0","doc":"Content type of protocol buffer format.","ref":"Prometheus.Format.Protobuf.html#content_type/0"},{"type":"function","title":"Prometheus.Format.Protobuf.format/1","doc":"Format `registry` (default is `:default`) using protocol buffer format.","ref":"Prometheus.Format.Protobuf.html#format/1"},{"type":"module","title":"Prometheus.Format.Text","doc":"Serializes Prometheus registry using the latest [text format](http://bit.ly/2cxSuJP).\n\nExample output:\n```\n# TYPE http_request_duration_milliseconds histogram\n# HELP http_request_duration_milliseconds Http Request execution time\nhttp_request_duration_milliseconds_bucket{method=\"post\",le=\"100\"} 0\nhttp_request_duration_milliseconds_bucket{method=\"post\",le=\"300\"} 1\nhttp_request_duration_milliseconds_bucket{method=\"post\",le=\"500\"} 3\nhttp_request_duration_milliseconds_bucket{method=\"post\",le=\"750\"} 4\nhttp_request_duration_milliseconds_bucket{method=\"post\",le=\"1000\"} 5\nhttp_request_duration_milliseconds_bucket{method=\"post\",le=\"+Inf\"} 6\nhttp_request_duration_milliseconds_count{method=\"post\"} 6\nhttp_request_duration_milliseconds_sum{method=\"post\"} 4350\n```","ref":"Prometheus.Format.Text.html"},{"type":"function","title":"Prometheus.Format.Text.content_type/0","doc":"Returns content type of the latest text format.","ref":"Prometheus.Format.Text.html#content_type/0"},{"type":"function","title":"Prometheus.Format.Text.format/1","doc":"Formats `registry` (default is `:default`) using the latest text format.","ref":"Prometheus.Format.Text.html#format/1"},{"type":"module","title":"Prometheus.Injector","doc":"Prometheus injector.","ref":"Prometheus.Injector.html"},{"type":"function","title":"Prometheus.Injector.inject/3","doc":"","ref":"Prometheus.Injector.html#inject/3"},{"type":"function","title":"Prometheus.Injector.inject_/2","doc":"","ref":"Prometheus.Injector.html#inject_/2"},{"type":"module","title":"Prometheus.Metric","doc":"Prometheus metrics shortcuts.\n\nAliases and requires respective metric modules so they are\naccessible without `Prometheus.Metric` prefix.\n\nAllows to automatically setup metrics with\n`@ ` attributes. Metrics will be declared in\nthe `@on_load` callback. If the module already\nhas `@on_load` callback, metrics will be declared\nif the callback returns `:ok`.\n\nExample:\n\n    iex(1)> defmodule MyCoolModule do\n    ...(1)>   use Prometheus.Metric\n    ...(1)>\n    ...(1)>   @counter name: :test_counter3, labels: [], help: \"qwe\"\n    ...(1)> end\n    iex(2)> require Prometheus.Metric.Counter\n    Prometheus.Metric.Counter\n    iex(3)> Prometheus.Metric.Counter.value(:test_counter3)\n    0","ref":"Prometheus.Metric.html"},{"type":"function","title":"Prometheus.Metric.parse_spec/1","doc":"","ref":"Prometheus.Metric.html#parse_spec/1"},{"type":"module","title":"Prometheus.Metric.Boolean","doc":"Boolean metric, to report booleans and flags.\n\nBoolean is a non-standard metric that uses untyped metric underneath.\n\nA Boolean is typically used as a flag i.e. enabled/disabled, online/offline.\n\nExample:\n```\n-module(my_fuse_instrumenter).\n\n-export([setup/0,\n         fuse_event/2]).\n\n setup() ->\n   prometheus_boolean:declare([{name, app_fuse_state},\n                               {labels, [name]}, %% fuse name\n                               {help, \"State of various app fuses.\"}]),\n\n fuse_event(Fuse, Event) ->\n   case Event of\n     ok -> prometheus_boolean:set(app_fuse_state, [Fuse], true);\n     blown -> prometheus_boolean:set(app_fuse_state, [Fuse], false);\n     _ -> ok\n   end.\n   ```","ref":"Prometheus.Metric.Boolean.html"},{"type":"function","title":"Prometheus.Metric.Boolean.declare/1","doc":"Creates a boolean using `spec`.\nIf a boolean with the same `spec` exists returns `false`.\n\nRaises `Prometheus.MissingMetricSpecKeyError` if required `spec` key is missing. \nRaises `Prometheus.InvalidMetricNameError` if metric name is invalid. \nRaises `Prometheus.InvalidMetricHelpError` if help is invalid. \nRaises `Prometheus.InvalidMetricLabelsError` if labels isn't a list. \nRaises `Prometheus.InvalidLabelNameError` if label name is invalid.","ref":"Prometheus.Metric.Boolean.html#declare/1"},{"type":"function","title":"Prometheus.Metric.Boolean.new/1","doc":"Creates a boolean using `spec`.\n\nRaises `Prometheus.MissingMetricSpecKeyError` if required `spec` key is missing. \nRaises `Prometheus.InvalidMetricNameError` if metric name is invalid. \nRaises `Prometheus.InvalidMetricHelpError` if help is invalid. \nRaises `Prometheus.InvalidMetricLabelsError` if labels isn't a list. \nRaises `Prometheus.InvalidLabelNameError` if label name is invalid. \nRaises `Prometheus.MFAlreadyExistsError` if a boolean with\nthe same `spec` already exists.","ref":"Prometheus.Metric.Boolean.html#new/1"},{"type":"function","title":"Prometheus.Metric.Boolean.remove/1","doc":"Removes boolean series identified by spec.\n\nRaises `Prometheus.UnknownMetricError` exception if a boolean\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Boolean.html#remove/1"},{"type":"function","title":"Prometheus.Metric.Boolean.reset/1","doc":"Resets the value of the boolean identified by `spec`.\n\nRaises `Prometheus.UnknownMetricError` exception if a boolean\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Boolean.html#reset/1"},{"type":"function","title":"Prometheus.Metric.Boolean.set/2","doc":"Sets the boolean identified by `spec` to `value`.\n\nValid \"truthy\" values:\n- `true`;\n- `false`;\n- `0` -> false;\n- `number > 0` -> true;\n- `[]` -> false\n- `non-empty list` -> true;\n- `:undefined` -> undefined\n\nOther values will generate `Prometheus.InvalidValueError` error.\n\nRaises `Prometheus.InvalidValueError` exception if `value` isn't\na boolean or `:undefined`. \nRaises `Prometheus.UnknownMetricError` exception if a boolean for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Boolean.html#set/2"},{"type":"function","title":"Prometheus.Metric.Boolean.toggle/1","doc":"Toggles the boolean identified by `spec` to `value`.\n\nRaises `Prometheus.InvalidValueError` exception if boolean is `:undefined`. \nRaises `Prometheus.UnknownMetricError` exception if a boolean for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Boolean.html#toggle/1"},{"type":"function","title":"Prometheus.Metric.Boolean.value/1","doc":"Returns the value of the boolean identified by `spec`. If there is no boolean for\ngiven labels combination, returns `:undefined`.\n\nRaises `Prometheus.UnknownMetricError` exception if a boolean\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Boolean.html#value/1"},{"type":"module","title":"Prometheus.Metric.Counter","doc":"Counter is a Metric that represents a single numerical value that only ever\ngoes up. That implies that it cannot be used to count items whose number can\nalso go down, e.g. the number of currently running processes. Those\n\"counters\" are represented by `Prometheus.Metric.Gauge`.\n\nA Counter is typically used to count requests served, tasks completed, errors\noccurred, etc.\n\nExample use cases for Counters:\n- Number of requests processed;\n- Number of items that were inserted into a queue;\n- Total amount of data that a system has processed.\n\nUse the [`rate()`](https://prometheus.io/docs/querying/functions/#rate())/\n[`irate()`](https://prometheus.io/docs/querying/functions/#irate())\nfunctions in Prometheus to calculate the rate of increase of a Counter.\nBy convention, the names of Counters are suffixed by `_total`.\n\nTo create a counter use either `new/1` or `declare/1`, the difference is that\n`new/` will raise `Prometheus.MFAlreadyExistsError` exception if counter with\nthe same `registry`, `name` and `labels` combination already exists.\nBoth accept `spec` `Keyword` with the same set of keys:\n\n- `:registry` - optional, default is `:default`;\n- `:name` - required, can be an atom or a string;\n- `:help` - required, must be a string;\n- `:labels` - optional, default is `[]`.\n\nExample:\n\n```\ndefmodule MyServiceInstrumenter do\n\n  use Prometheus.Metric","ref":"Prometheus.Metric.Counter.html"},{"type":"module","title":"to be called at app/supervisor startup. - Prometheus.Metric.Counter","doc":"","ref":"Prometheus.Metric.Counter.html#module-to-be-called-at-app-supervisor-startup"},{"type":"module","title":"to tolerate restarts use declare. - Prometheus.Metric.Counter","doc":"def setup() do\n    Counter.declare([name: :my_service_requests_total,\n                     help: \"Requests count.\",\n                     labels: [:caller]])\n  end\n\n  def inc(caller) do\n    Counter.inc([name: :my_service_requests_total,\n                labels: [caller]])\n  end\n\nend\n\n```","ref":"Prometheus.Metric.Counter.html#module-to-tolerate-restarts-use-declare"},{"type":"macro","title":"Prometheus.Metric.Counter.count/2","doc":"Increments the counter identified by `spec` by 1 when `body` executed.\n\nRead more about bodies: `Prometheus.Injector`.\n\nRaises `Prometheus.UnknownMetricError` exception if a counter\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Counter.html#count/2"},{"type":"macro","title":"Prometheus.Metric.Counter.count_exceptions/3","doc":"Increments the counter identified by `spec` by 1 when `body` raises `exception`.\n\nRead more about bodies: `Prometheus.Injector`.\n\nRaises `Prometheus.UnknownMetricError` exception if a counter\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Counter.html#count_exceptions/3"},{"type":"macro","title":"Prometheus.Metric.Counter.count_no_exceptions/2","doc":"Increments the counter identified by `spec` by 1 when `body` raises no exceptions.\n\nRead more about bodies: `Prometheus.Injector`.\n\nRaises `Prometheus.UnknownMetricError` exception if a counter\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Counter.html#count_no_exceptions/2"},{"type":"function","title":"Prometheus.Metric.Counter.declare/1","doc":"Creates a counter using `spec`.\nIf a counter with the same `spec` exists returns `false`.\n\nRaises `Prometheus.MissingMetricSpecKeyError` if required `spec` key is missing. \nRaises `Prometheus.InvalidMetricNameError` if metric name is invalid. \nRaises `Prometheus.InvalidMetricHelpError` if help is invalid. \nRaises `Prometheus.InvalidMetricLabelsError` if labels isn't a list. \nRaises `Prometheus.InvalidLabelNameError` if label name is invalid.","ref":"Prometheus.Metric.Counter.html#declare/1"},{"type":"function","title":"Prometheus.Metric.Counter.inc/2","doc":"Increments the counter identified by `spec` by `value`.\n\nRaises `Prometheus.InvalidValueError` exception if `value` isn't a positive number. \nRaises `Prometheus.UnknownMetricError` exception if a counter\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Counter.html#inc/2"},{"type":"function","title":"Prometheus.Metric.Counter.new/1","doc":"Creates a counter using `spec`.\n\nRaises `Prometheus.MissingMetricSpecKeyError` if required `spec` key is missing. \nRaises `Prometheus.InvalidMetricNameError` if metric name is invalid. \nRaises `Prometheus.InvalidMetricHelpError` if help is invalid. \nRaises `Prometheus.InvalidMetricLabelsError` if labels isn't a list. \nRaises `Prometheus.InvalidLabelNameError` if label name is invalid. \nRaises `Prometheus.MFAlreadyExistsError` if a counter with\nthe same `spec` already exists.","ref":"Prometheus.Metric.Counter.html#new/1"},{"type":"function","title":"Prometheus.Metric.Counter.remove/1","doc":"Removes counter series identified by spec.\n\nRaises `Prometheus.UnknownMetricError` exception if a counter\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Counter.html#remove/1"},{"type":"function","title":"Prometheus.Metric.Counter.reset/1","doc":"Resets the value of the counter identified by `spec`.\n\nRaises `Prometheus.UnknownMetricError` exception if a counter\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Counter.html#reset/1"},{"type":"function","title":"Prometheus.Metric.Counter.value/1","doc":"Returns the value of the counter identified by `spec`. If there is no counter for\ngiven labels combination, returns `:undefined`.\n\nRaises `Prometheus.UnknownMetricError` exception if a counter\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Counter.html#value/1"},{"type":"module","title":"Prometheus.Metric.Gauge","doc":"Gauge metric, to report instantaneous values.\n\nGauge is a metric that represents a single numerical value that can\narbitrarily go up and down.\n\nA Gauge is typically used for measured values like temperatures or current\nmemory usage, but also \"counts\" that can go up and down, like the number of\nrunning processes.\n\nExample use cases for Gauges:\n  - In progress requests;\n  - Number of items in a queue;\n  - Free memory;\n  - Total memory;\n  - Temperature.\n\nExample:\n\n```\ndefmodule MyPoolInstrumenter do\n\n  use Prometheus.Metric","ref":"Prometheus.Metric.Gauge.html"},{"type":"module","title":"to be called at app/supervisor startup. - Prometheus.Metric.Gauge","doc":"","ref":"Prometheus.Metric.Gauge.html#module-to-be-called-at-app-supervisor-startup"},{"type":"module","title":"to tolerate restarts use declare. - Prometheus.Metric.Gauge","doc":"def setup() do\n    Gauge.declare([name: :my_pool_size,\n                   help: \"Pool size.\"])\n\n    Gauge.declare([name: :my_pool_checked_out,\n                   help: \"Number of sockets checked out from the pool\"])\n  end\n\n  def set_size(size) do\n    Gauge.set([name: :my_pool_size], size)\n  end\n\n  def track_checked_out_sockets(checkout_fun) do\n    Gauge.track_inprogress([name: :my_pool_checked_out], checkout_fun.())\n  end\n\n  def track_checked_out_sockets_block(socket) do\n    Gauge.track_inprogress([name: :my_pool_checked_out]) do\n      # checkout code\n      socket\n    end\n  end\n\nend\n\n```","ref":"Prometheus.Metric.Gauge.html#module-to-tolerate-restarts-use-declare"},{"type":"function","title":"Prometheus.Metric.Gauge.dec/2","doc":"Decrements the gauge identified by `spec` by `value`.\n\nRaises `Prometheus.InvalidValueError` exception if `value` isn't a number. \nRaises `Prometheus.UnknownMetricError` exception if a gauge for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Gauge.html#dec/2"},{"type":"function","title":"Prometheus.Metric.Gauge.declare/1","doc":"Creates a gauge using `spec`.\nIf a gauge with the same `spec` exists returns `false`.\n\nRaises `Prometheus.MissingMetricSpecKeyError` if required `spec` key is missing. \nRaises `Prometheus.InvalidMetricNameError` if metric name is invalid. \nRaises `Prometheus.InvalidMetricHelpError` if help is invalid. \nRaises `Prometheus.InvalidMetricLabelsError` if labels isn't a list. \nRaises `Prometheus.InvalidMetricNameError` if label name is invalid. \nRaises `Prometheus.InvalidValueError` exception if duration_unit is unknown or\ndoesn't match metric name.","ref":"Prometheus.Metric.Gauge.html#declare/1"},{"type":"function","title":"Prometheus.Metric.Gauge.inc/2","doc":"Increments the gauge identified by `spec` by `value`.\n\nRaises `Prometheus.InvalidValueError` exception if `value` isn't a number. \nRaises `Prometheus.UnknownMetricError` exception if a gauge for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Gauge.html#inc/2"},{"type":"function","title":"Prometheus.Metric.Gauge.new/1","doc":"Creates a gauge using `spec`.\n\nRaises `Prometheus.MissingMetricSpecKeyError` if required `spec` key is missing. \nRaises `Prometheus.InvalidMetricNameError` if metric name is invalid. \nRaises `Prometheus.InvalidMetricHelpError` if help is invalid. \nRaises `Prometheus.InvalidMetricLabelsError` if labels isn't a list. \nRaises `Prometheus.InvalidMetricNameError` if label name is invalid. \nRaises `Prometheus.InvalidValueError` exception if duration_unit is unknown or\ndoesn't match metric name. \nRaises `Prometheus.MFAlreadyExistsError` if a gauge with the same `spec` exists.","ref":"Prometheus.Metric.Gauge.html#new/1"},{"type":"function","title":"Prometheus.Metric.Gauge.remove/1","doc":"Removes gauge series identified by spec.\n\nRaises `Prometheus.UnknownMetricError` exception if a gauge\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Gauge.html#remove/1"},{"type":"function","title":"Prometheus.Metric.Gauge.reset/1","doc":"Resets the value of the gauge identified by `spec`.\n\nRaises `Prometheus.UnknownMetricError` exception if a gauge\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Gauge.html#reset/1"},{"type":"function","title":"Prometheus.Metric.Gauge.set/2","doc":"Sets the gauge identified by `spec` to `value`.\n\nRaises `Prometheus.InvalidValueError` exception if `value` isn't\na number or `:undefined`. \nRaises `Prometheus.UnknownMetricError` exception if a gauge for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Gauge.html#set/2"},{"type":"macro","title":"Prometheus.Metric.Gauge.set_duration/2","doc":"Tracks the amount of time spent executing `body`.\n\nRaises `Prometheus.UnknownMetricError` exception if a gauge\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.\nRaises `Prometheus.InvalidValueError` exception if `fun` isn't a function or block.","ref":"Prometheus.Metric.Gauge.html#set_duration/2"},{"type":"function","title":"Prometheus.Metric.Gauge.set_to_current_time/1","doc":"Sets the gauge identified by `spec` to the current unix time.\n\nRaises `Prometheus.UnknownMetricError` exception if a gauge\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Gauge.html#set_to_current_time/1"},{"type":"macro","title":"Prometheus.Metric.Gauge.track_inprogress/2","doc":"Sets the gauge identified by `spec` to the number of currently executing `body`s.\n\nRaises `Prometheus.UnknownMetricError` exception if a gauge\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.\nRaises `Prometheus.InvalidValueError` exception if fun isn't a function or block.","ref":"Prometheus.Metric.Gauge.html#track_inprogress/2"},{"type":"function","title":"Prometheus.Metric.Gauge.value/1","doc":"Returns the value of the gauge identified by `spec`.\n\nIf duration unit set, value will be converted to the duration unit.\n[Read more here.](time.html)\n\nRaises `Prometheus.UnknownMetricError` exception if a gauge\nfor `spec` can't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Gauge.html#value/1"},{"type":"module","title":"Prometheus.Metric.Histogram","doc":"A Histogram tracks the size and number of events in buckets.\nYou can use Histograms for aggregating calculation of quantiles.\n\nExample use cases for Histograms:\n  - Response latency;\n  - Request size.\n\nHistogram expects `buckets` key in a metric spec. Buckets can be:\n - a list of numbers in increasing order;\n - one of the generate specs (shortcuts for `Prometheus.Buckets` macros)\n     - `:default`;\n     - `{:linear, start, step, count}`;\n     - `{:exponential, start, step, count}`.\n\nExample:\n\n```\n\ndefmodule ExampleInstrumenter do\n  use Prometheus.Metric","ref":"Prometheus.Metric.Histogram.html"},{"type":"module","title":"to be called at app/supervisor startup. - Prometheus.Metric.Histogram","doc":"","ref":"Prometheus.Metric.Histogram.html#module-to-be-called-at-app-supervisor-startup"},{"type":"module","title":"to tolerate restarts use declare. - Prometheus.Metric.Histogram","doc":"def setup do\n    Histogram.new([name: :http_request_duration_milliseconds,\n                   labels: [:method],\n                   buckets: [100, 300, 500, 750, 1000],\n                   help: \"Http Request execution time.\"])\n  end\n\n  def instrument(%{time: time, method: method}) do\n    Histogram.observe([name: :http_request_duration_milliseconds, labels: [method]],\n                      time)\n  end\nend\n\n```","ref":"Prometheus.Metric.Histogram.html#module-to-tolerate-restarts-use-declare"},{"type":"function","title":"Prometheus.Metric.Histogram.declare/1","doc":"Creates a histogram using `spec`.\nHistogram cannot have a label named \"le\".\n\nIf a histogram with the same `spec` exists returns `false`.\n\nRaises `Prometheus.MissingMetricSpecKeyError` if required `spec` key is missing. \nRaises `Prometheus.InvalidMetricNameError` if metric name is invalid. \nRaises `Prometheus.InvalidMetricHelpError` if help is invalid. \nRaises `Prometheus.InvalidMetricLabelsError` if labels isn't a list. \nRaises `Prometheus.InvalidMetricNameError` if label name is invalid. \nRaises `Prometheus.InvalidValueError` exception if duration_unit is unknown or\ndoesn't match metric name.\n\nHistogram-specific exceptions:\n\nRaises `Prometheus.HistogramNoBucketsError` if buckets are missing, not a list,\nempty list or not known buckets spec. \nRaises `Prometheus.HistogramInvalidBucketsError` if buckets aren't\nin increasing order. \nRaises `Prometheus.HistogramInvalidBoundError` if bucket bound isn't a number.","ref":"Prometheus.Metric.Histogram.html#declare/1"},{"type":"function","title":"Prometheus.Metric.Histogram.new/1","doc":"Creates a histogram using `spec`.\nHistogram cannot have a label named \"le\".\n\nRaises `Prometheus.MissingMetricSpecKeyError` if required `spec` key is missing. \nRaises `Prometheus.InvalidMetricNameError` if metric name is invalid. \nRaises `Prometheus.InvalidMetricHelpError` if help is invalid. \nRaises `Prometheus.InvalidMetricLabelsError` if labels isn't a list. \nRaises `Prometheus.InvalidMetricNameError` if label name is invalid. \nRaises `Prometheus.InvalidValueError` exception if duration_unit is unknown or\ndoesn't match metric name. \nRaises `Prometheus.MFAlreadyExistsError` if a histogram with the same `spec` exists.\n\nHistogram-specific exceptions:\n\nRaises `Prometheus.HistogramNoBucketsError` if buckets are missing, not a list,\nempty list or not known buckets spec. \nRaises `Prometheus.HistogramInvalidBucketsError` if buckets aren't\nin increasing order. \nRaises `Prometheus.HistogramInvalidBoundError` if bucket bound isn't a number.","ref":"Prometheus.Metric.Histogram.html#new/1"},{"type":"function","title":"Prometheus.Metric.Histogram.observe/2","doc":"Observes the given amount.\n\nRaises `Prometheus.InvalidValueError` exception if `amount` isn't\na number. \nRaises `Prometheus.UnknownMetricError` exception if a histogram for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Histogram.html#observe/2"},{"type":"macro","title":"Prometheus.Metric.Histogram.observe_duration/2","doc":"Observes the amount of time spent executing `body`.\n\nRaises `Prometheus.UnknownMetricError` exception if a histogram for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.\nRaises `Prometheus.InvalidValueError` exception if fun isn't a function or block.","ref":"Prometheus.Metric.Histogram.html#observe_duration/2"},{"type":"function","title":"Prometheus.Metric.Histogram.remove/1","doc":"Removes histogram series identified by spec.\n\nRaises `Prometheus.UnknownMetricError` exception if a histogram for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Histogram.html#remove/1"},{"type":"function","title":"Prometheus.Metric.Histogram.reset/1","doc":"Resets the value of the histogram identified by `spec`.\n\nRaises `Prometheus.UnknownMetricError` exception if a histogram for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Histogram.html#reset/1"},{"type":"function","title":"Prometheus.Metric.Histogram.value/1","doc":"Returns the value of the histogram identified by `spec`. If there is no histogram for\ngiven labels combination, returns `:undefined`.\n\nRaises `Prometheus.UnknownMetricError` exception if a histogram for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Histogram.html#value/1"},{"type":"module","title":"Prometheus.Metric.Summary","doc":"Summary metric, to track the size of events.\n\nExample use cases for Summaries:\n  - Response latency;\n  - Request size;\n  - Response size.\n\nExample:\n\n```\ndefmodule MyProxyInstrumenter do\n\n  use Prometheus.Metric","ref":"Prometheus.Metric.Summary.html"},{"type":"module","title":"to be called at app/supervisor startup. - Prometheus.Metric.Summary","doc":"","ref":"Prometheus.Metric.Summary.html#module-to-be-called-at-app-supervisor-startup"},{"type":"module","title":"to tolerate restarts use declare. - Prometheus.Metric.Summary","doc":"def setup() do\n    Summary.declare([name: :request_size_bytes,\n                     help: \"Request size in bytes.\"])\n\n    Summary.declare([name: :response_size_bytes,\n                     help: \"Response size in bytes.\"])\n  end\n\n  def observe_request(size) do\n    Summary.observe([name: :request_size_bytes], size)\n  end\n\n  def observe_response(size) do\n    Summary.observe([name: :response_size_bytes], size)\n  end\nend\n```","ref":"Prometheus.Metric.Summary.html#module-to-tolerate-restarts-use-declare"},{"type":"function","title":"Prometheus.Metric.Summary.declare/1","doc":"Creates a summary using `spec`.\nSummary cannot have a label named \"quantile\".\n\nIf a summary with the same `spec` exists returns `false`.\n\nRaises `Prometheus.MissingMetricSpecKeyError` if required `spec` key is missing. \nRaises `Prometheus.InvalidMetricNameError` if metric name is invalid. \nRaises `Prometheus.InvalidMetricHelpError` if help is invalid. \nRaises `Prometheus.InvalidMetricLabelsError` if labels isn't a list. \nRaises `Prometheus.InvalidMetricNameError` if label name is invalid; \nRaises `Prometheus.InvalidValueError` exception if duration_unit is unknown or\ndoesn't match metric name.","ref":"Prometheus.Metric.Summary.html#declare/1"},{"type":"function","title":"Prometheus.Metric.Summary.new/1","doc":"Creates a summary using `spec`.\nSummary cannot have a label named \"quantile\".\n\nRaises `Prometheus.MissingMetricSpecKeyError` if required `spec` key is missing. \nRaises `Prometheus.InvalidMetricNameError` if metric name is invalid. \nRaises `Prometheus.InvalidMetricHelpError` if help is invalid. \nRaises `Prometheus.InvalidMetricLabelsError` if labels isn't a list. \nRaises `Prometheus.InvalidMetricNameError` if label name is invalid. \nRaises `Prometheus.InvalidValueError` exception if duration_unit is unknown or\ndoesn't match metric name. \nRaises `Prometheus.MFAlreadyExistsError` if a summary with the same `spec`\nalready exists.","ref":"Prometheus.Metric.Summary.html#new/1"},{"type":"function","title":"Prometheus.Metric.Summary.observe/2","doc":"Observes the given amount.\n\nRaises `Prometheus.InvalidValueError` exception if `amount` isn't a number. \nRaises `Prometheus.UnknownMetricError` exception if a summary for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Summary.html#observe/2"},{"type":"macro","title":"Prometheus.Metric.Summary.observe_duration/2","doc":"Observes the amount of time spent executing `body`.\n\nRaises `Prometheus.UnknownMetricError` exception if a summary for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.\nRaises `Prometheus.InvalidValueError` exception if `fun` isn't a function or block.","ref":"Prometheus.Metric.Summary.html#observe_duration/2"},{"type":"function","title":"Prometheus.Metric.Summary.remove/1","doc":"Removes summary series identified by spec.\n\nRaises `Prometheus.UnknownMetricError` exception if a summary for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Summary.html#remove/1"},{"type":"function","title":"Prometheus.Metric.Summary.reset/1","doc":"Resets the value of the summary identified by `spec`.\n\nRaises `Prometheus.UnknownMetricError` exception if a summary for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Summary.html#reset/1"},{"type":"function","title":"Prometheus.Metric.Summary.value/1","doc":"Returns the value of the summary identified by `spec`. If there is no summary for\ngiven labels combination, returns `:undefined`.\n\nIf duration unit set, sum will be converted to the duration unit.\n[Read more here.](time.html)\n\nRaises `Prometheus.UnknownMetricError` exception if a summary for `spec`\ncan't be found. \nRaises `Prometheus.InvalidMetricArityError` exception if labels count mismatch.","ref":"Prometheus.Metric.Summary.html#value/1"},{"type":"module","title":"Prometheus.Model","doc":"Helpers for working with Prometheus data model. For advanced users.\n\n`Prometheus.Collector` example demonstrates how to use this module.","ref":"Prometheus.Model.html"},{"type":"function","title":"Prometheus.Model.counter_metric/2","doc":"Creates counter metric with `labels` and `value`.\n\n    iex(15)> Prometheus.Model.counter_metric([host: \"example.com\"], 100)\n    {:Metric, [{:LabelPair, \"host\", \"example.com\"}], :undefined, {:Counter, 100},\n    :undefined, :undefined, :undefined, :undefined}","ref":"Prometheus.Model.html#counter_metric/2"},{"type":"function","title":"Prometheus.Model.counter_metrics/1","doc":"Creates counter metrics from `mdata` {labels, value} tuple list.\n\n    iex(14)> Prometheus.Model.counter_metrics([{[host: \"example.com\"], 100}])\n    [{:Metric, [{:LabelPair, \"host\", \"example.com\"}], :undefined, {:Counter, 100},\n    :undefined, :undefined, :undefined, :undefined}]","ref":"Prometheus.Model.html#counter_metrics/1"},{"type":"function","title":"Prometheus.Model.create_mf/5","doc":"Creates Metric Family of `type`, `name` and `help`.\n`collector.collect_metrics/2` callback will be called and expected to\nreturn individual metrics list.","ref":"Prometheus.Model.html#create_mf/5"},{"type":"function","title":"Prometheus.Model.gauge_metric/2","doc":"Creates gauge metric with `labels` and `value`.\n\n    iex(13)> Prometheus.Model.gauge_metric([host: \"example.com\"], 100)\n    {:Metric, [{:LabelPair, \"host\", \"example.com\"}], {:Gauge, 100}, :undefined,\n     :undefined, :undefined, :undefined, :undefined}","ref":"Prometheus.Model.html#gauge_metric/2"},{"type":"function","title":"Prometheus.Model.gauge_metrics/1","doc":"Creates gauge metrics from `mdata` {label, value} tuple list.\n\n    iex(11)> Prometheus.Model.gauge_metrics([{[host: \"example.com\"], 100}])\n    [{:Metric, [{:LabelPair, \"host\", \"example.com\"}], {:Gauge, 100}, :undefined,\n    :undefined, :undefined, :undefined, :undefined}]","ref":"Prometheus.Model.html#gauge_metrics/1"},{"type":"function","title":"Prometheus.Model.histogram_metric/4","doc":"Creates histogram metric with `labels`, `buckets`, `count`, and `sum`.\n\n    iex(4)> Prometheus.Model.histogram_metric([{:method, :get}],\n    ...(4)>                                    [{2, 1}, {5, 1}, {:infinity, 2}],\n    ...(4)>                                    2, 10.5)\n    {:Metric, [{:LabelPair, \"method\", \"get\"}], :undefined, :undefined, :undefined,\n    :undefined,\n    {:Histogram, 2, 10.5,\n    [{:Bucket, 1, 2}, {:Bucket, 1, 5}, {:Bucket, 2, :infinity}]}, :undefined}\n\nBuckets is a list of pairs {upper_bound, cumulative_count}.\nCumulative count is a sum of all cumulative_counts of previous buckets + counter of\ncurrent bucket.","ref":"Prometheus.Model.html#histogram_metric/4"},{"type":"function","title":"Prometheus.Model.histogram_metrics/1","doc":"Creates histogram metrics from `mdata` {labels, buckets, count, sum} tuple list.\n\n    iex(2)> Prometheus.Model.histogram_metrics([{[{:method, :get}],\n    ...(2)>                                      [{2, 1}, {5, 1}, {:infinity, 2}],\n    ...(2)>                                      2, 10.5}])\n    [{:Metric, [{:LabelPair, \"method\", \"get\"}], :undefined, :undefined, :undefined,\n      :undefined,\n      {:Histogram, 2, 10.5,\n       [{:Bucket, 1, 2}, {:Bucket, 1, 5}, {:Bucket, 2, :infinity}]}, :undefined}]","ref":"Prometheus.Model.html#histogram_metrics/1"},{"type":"function","title":"Prometheus.Model.summary_metric/3","doc":"Creates summary metric with `labels`, `count`, and `sum`.\n\n    iex(3)> Prometheus.Model.summary_metric([{:method, :get}], 2, 10.5)\n    {:Metric, [{:LabelPair, \"method\", \"get\"}], :undefined, :undefined,\n      {:Summary, 2, 10.5, []}, :undefined, :undefined, :undefined}","ref":"Prometheus.Model.html#summary_metric/3"},{"type":"function","title":"Prometheus.Model.summary_metrics/1","doc":"Creates summary metrics from `mdata` {labels, count, sum} tuple list.\n\n    iex(7)> Prometheus.Model.summary_metrics([{[{:method, :get}], 2, 10.5}])\n    [{:Metric, [{:LabelPair, \"method\", \"get\"}], :undefined, :undefined,\n      {:Summary, 2, 10.5, []}, :undefined, :undefined, :undefined}]","ref":"Prometheus.Model.html#summary_metrics/1"},{"type":"function","title":"Prometheus.Model.untyped_metric/2","doc":"Creates untyped metric with `labels` and `value`.\n\n    iex(13)> Prometheus.Model.untyped_metric([host: \"example.com\"], 100)\n    {:Metric, [{:LabelPair, \"host\", \"example.com\"}], :undefined,\n     :undefined, :undefined, {:Untyped, 100}, :undefined, :undefined}","ref":"Prometheus.Model.html#untyped_metric/2"},{"type":"function","title":"Prometheus.Model.untyped_metrics/1","doc":"Creates untyped metrics from `mdata` {label, value} tuple list.\n\n    iex(11)> Prometheus.Model.untyped_metrics([{[host: \"example.com\"], 100}])\n    [{:Metric, [{:LabelPair, \"host\", \"example.com\"}], :undefined,\n    :undefined, :undefined, {:Untyped, 100}, :undefined, :undefined}]","ref":"Prometheus.Model.html#untyped_metrics/1"},{"type":"module","title":"Prometheus.Registry","doc":"A registry of Collectors.\n\nThe majority of users should use the `:default`, rather than their own.\n\nCreating a registry other than the default is primarily useful for\nunit tests, or pushing a subset of metrics to the\n[Pushgateway](https://github.com/prometheus/pushgateway) from batch jobs.","ref":"Prometheus.Registry.html"},{"type":"function","title":"Prometheus.Registry.clear/1","doc":"Unregisters all collectors.","ref":"Prometheus.Registry.html#clear/1"},{"type":"function","title":"Prometheus.Registry.collect/2","doc":"Calls `callback` for each collector with two arguments: `registry` and `collector`.","ref":"Prometheus.Registry.html#collect/2"},{"type":"function","title":"Prometheus.Registry.collector_registered?/2","doc":"Checks whether `collector` is registered.","ref":"Prometheus.Registry.html#collector_registered?/2"},{"type":"function","title":"Prometheus.Registry.collectors/1","doc":"Returns collectors registered in `registry`.","ref":"Prometheus.Registry.html#collectors/1"},{"type":"function","title":"Prometheus.Registry.deregister_collector/2","doc":"Unregisters a collector.","ref":"Prometheus.Registry.html#deregister_collector/2"},{"type":"function","title":"Prometheus.Registry.exists/1","doc":"Tries to find registry with the `name`.\nAssumes that registry name is always an atom.\nIf `Name` is an atom `ets:lookup/2` is used\nIf `Name` is an iolist performs safe search (to avoid interning\natoms) and returns atom or false. This operation is O(n).","ref":"Prometheus.Registry.html#exists/1"},{"type":"function","title":"Prometheus.Registry.register_collector/2","doc":"Registers a collector.","ref":"Prometheus.Registry.html#register_collector/2"},{"type":"function","title":"Prometheus.Registry.register_collectors/2","doc":"Registers collectors list.","ref":"Prometheus.Registry.html#register_collectors/2"},{"type":"exception","title":"Prometheus.Config.KeyNotFoundError","doc":"Raised when mandatory configuration option not found in app env.","ref":"Prometheus.Config.KeyNotFoundError.html"},{"type":"function","title":"Prometheus.Config.KeyNotFoundError.message/1","doc":"","ref":"Prometheus.Config.KeyNotFoundError.html#message/1"},{"type":"exception","title":"Prometheus.InvalidBlockArityError","doc":"Raised when fn passed as block has more then 0 arguments","ref":"Prometheus.InvalidBlockArityError.html"},{"type":"function","title":"Prometheus.InvalidBlockArityError.message/1","doc":"","ref":"Prometheus.InvalidBlockArityError.html#message/1"},{"type":"exception","title":"Prometheus.InvalidBoundError","doc":"Raised by histogram constructors when bucket bound isn't a number.","ref":"Prometheus.InvalidBoundError.html"},{"type":"function","title":"Prometheus.InvalidBoundError.message/1","doc":"","ref":"Prometheus.InvalidBoundError.html#message/1"},{"type":"exception","title":"Prometheus.InvalidBucketsError","doc":"Raised by histogram constructors when buckets are invalid i.e. not sorted in increasing\norder or generator spec is unknown.","ref":"Prometheus.InvalidBucketsError.html"},{"type":"function","title":"Prometheus.InvalidBucketsError.message/1","doc":"","ref":"Prometheus.InvalidBucketsError.html#message/1"},{"type":"exception","title":"Prometheus.InvalidLabelNameError","doc":"Raised when label `name` is invalid i.e. can't be represented as printable utf-8 string\nthat matches `^[a-zA-Z_][a-zA-Z0-9_]*$` regular expression or starts with `__`.\n\nMetric can impose further restrictions on label names.","ref":"Prometheus.InvalidLabelNameError.html"},{"type":"function","title":"Prometheus.InvalidLabelNameError.message/1","doc":"","ref":"Prometheus.InvalidLabelNameError.html#message/1"},{"type":"exception","title":"Prometheus.InvalidMetricArityError","doc":"Raised when metric arity is invalid e.g. counter metric was created with two labels but\nonly one label value is passed to `Prometheus.Metric.Counter.inc/2`.","ref":"Prometheus.InvalidMetricArityError.html"},{"type":"function","title":"Prometheus.InvalidMetricArityError.message/1","doc":"","ref":"Prometheus.InvalidMetricArityError.html#message/1"},{"type":"exception","title":"Prometheus.InvalidMetricHelpError","doc":"Raised when given metric `help` is invalid i.e. isn't a printable utf-8 string.","ref":"Prometheus.InvalidMetricHelpError.html"},{"type":"function","title":"Prometheus.InvalidMetricHelpError.message/1","doc":"","ref":"Prometheus.InvalidMetricHelpError.html#message/1"},{"type":"exception","title":"Prometheus.InvalidMetricLabelsError","doc":"Raised when `labels` isn't a list.","ref":"Prometheus.InvalidMetricLabelsError.html"},{"type":"function","title":"Prometheus.InvalidMetricLabelsError.message/1","doc":"","ref":"Prometheus.InvalidMetricLabelsError.html#message/1"},{"type":"exception","title":"Prometheus.InvalidMetricNameError","doc":"Raised when given metric `name` is invalid i.e. can't be represented as printable utf-8\nstring that matches `^[a-zA-Z_:][a-zA-Z0-9_:]*$` regular expression.","ref":"Prometheus.InvalidMetricNameError.html"},{"type":"function","title":"Prometheus.InvalidMetricNameError.message/1","doc":"","ref":"Prometheus.InvalidMetricNameError.html#message/1"},{"type":"exception","title":"Prometheus.InvalidValueError","doc":"Raised when given `value` is invalid i.e. when you pass a negative number to\n`Prometheus.Metric.Counter.inc/2`.","ref":"Prometheus.InvalidValueError.html"},{"type":"function","title":"Prometheus.InvalidValueError.message/1","doc":"","ref":"Prometheus.InvalidValueError.html#message/1"},{"type":"exception","title":"Prometheus.MFAlreadyExistsError","doc":"Raised when one tries to create metric in `registry` with `name` it already exists.","ref":"Prometheus.MFAlreadyExistsError.html"},{"type":"function","title":"Prometheus.MFAlreadyExistsError.message/1","doc":"","ref":"Prometheus.MFAlreadyExistsError.html#message/1"},{"type":"exception","title":"Prometheus.MissingMetricSpecKeyError","doc":"Raised when required metric `spec` `key` is missing. All metrics\nrequire at least `name` and when metric created `help`.\n\nMetrics can have their specific required keys.","ref":"Prometheus.MissingMetricSpecKeyError.html"},{"type":"function","title":"Prometheus.MissingMetricSpecKeyError.message/1","doc":"","ref":"Prometheus.MissingMetricSpecKeyError.html#message/1"},{"type":"exception","title":"Prometheus.NoBucketsError","doc":"Raised by histogram constructors when buckets can't be found in spec, or\nfound value is empty list.","ref":"Prometheus.NoBucketsError.html"},{"type":"function","title":"Prometheus.NoBucketsError.message/1","doc":"","ref":"Prometheus.NoBucketsError.html#message/1"},{"type":"exception","title":"Prometheus.UnknownMetricError","doc":"","ref":"Prometheus.UnknownMetricError.html"},{"type":"function","title":"Prometheus.UnknownMetricError.message/1","doc":"","ref":"Prometheus.UnknownMetricError.html#message/1"},{"type":"extras","title":"Mnesia Collector","doc":"/* chrome bug workaround */\n.content-inner li pre{overflow: inherit;}\n \n# Mnesia Collector\nCollects Mnesia metrics mainly using\n[:mnesia:system_info/1](http://erlang.org/doc/man/mnesia.html#system_info-1).","ref":"mnesia-collector.html"},{"type":"extras","title":"Exported metrics - Mnesia Collector","doc":"erlang_mnesia_held_locks \n    Type: gauge. \n    Number of held locks.\n   \n   \n     erlang_mnesia_lock_queue \n    Type: gauge. \n    Number of transactions waiting for a lock.\n   \n   \n     erlang_mnesia_transaction_participants \n    Type: gauge. \n    Number of participant transactions.\n   \n   \n     erlang_mnesia_transaction_coordinators \n    Type: gauge. \n    Number of coordinator transactions.\n   \n   \n     erlang_mnesia_failed_transactions \n    Type: counter. \n    Number of failed (i.e. aborted) transactions.\n   \n   \n     erlang_mnesia_committed_transactions \n    Type: gauge. \n    Number of committed transactions.\n   \n   \n     erlang_mnesia_logged_transactions \n    Type: counter. \n    Number of transactions logged.\n   \n   \n     erlang_mnesia_restarted_transactions \n    Type: counter. \n    Total number of transaction restarts.","ref":"mnesia-collector.html#exported-metrics"},{"type":"extras","title":"Configuration - Mnesia Collector","doc":"Metrics exported by this collector can be configured via\n`mnesia_collector_metrics` key of `prometheus` app environment.\n\nAvailable options:\n - `:held_locks` for `erlang_mnesia_held_locks`;\n - `:lock_queue` for `erlang_mnesia_lock_queue`;\n - `:transaction_participants` for `erlang_mnesia_transaction_participants`;\n - `:transaction_coordinators` for `erlang_mnesia_transaction_coordinators`;\n - `:transaction_failures` for `erlang_mnesia_failed_transactions`;\n - `:transaction_commits` for `erlang_mnesia_committed_transactions`;\n - `:transaction_log_writes` for `erlang_mnesia_logged_transactions`;\n - `:transaction_restarts` for `erlang_mnesia_restarted_transactions`.\n\nBy default all metrics are enabled.","ref":"mnesia-collector.html#configuration"},{"type":"extras","title":"VM Memory Collector","doc":"/* chrome bug workaround */\n.content-inner li pre{overflow: inherit;}\n \n# VM Memory Collector\nCollects information about memory dynamically allocated\nby the Erlang emulator using\n[:erlang.memory/0](http://erlang.org/doc/man/erlang.html#memory-0).\nAlso provides basic (D)ETS statistics.","ref":"vm-memory-collector.html"},{"type":"extras","title":"Exported metrics - VM Memory Collector","doc":"erlang_vm_memory_atom_bytes_total \n\tType: gauge. \n    Labels:\n     \n       usage=\"free\"|\"used\". \n     \n     \n    The total amount of memory currently allocated for atoms.\n    This memory is part of the memory presented as system memory.\n   \n   \n     erlang_vm_memory_bytes_total \n\tType: gauge. \n    Labels:\n     \n       kind=\"system\"|\"processes\". \n     \n     \n    The total amount of memory currently allocated.\n    This is the same as the sum of the memory size for processes and system.\n   \n   \n     erlang_vm_dets_tables \n\tType: gauge. \n    Erlang VM DETS Tables count.\n   \n   \n     erlang_vm_ets_tables \n\tType: gauge. \n    Erlang VM ETS Tables count.\n   \n   \n     erlang_vm_memory_processes_bytes_total \n\tType: gauge. \n    Labels:\n     \n       usage=\"used\"|\"free\". \n     \n     \n    The total amount of memory currently allocated for the Erlang processes.\n   \n   \n     erlang_vm_memory_system_bytes_total \n\tType: gauge. \n    Labels:\n     \n       usage=\"atom\"|\"binary\"|\"code\"|\"ets\"|\"other\". \n     \n     \n    The total amount of memory currently allocated for the emulator\n    that is not directly related to any Erlang process.\n    Memory presented as processes is not included in this memory.","ref":"vm-memory-collector.html#exported-metrics"},{"type":"extras","title":"Configuration - VM Memory Collector","doc":"Metrics exported by this collector can be configured via\n`:vm_memory_collector_metrics` key of `:prometheus` app environment.\n\nAvailable options:\n - `:atom_bytes_total` for `erlang_vm_memory_atom_bytes_total`;\n - `:bytes_total` for `erlang_vm_memory_bytes_total`;\n - `:dets_tables` for `erlang_vm_dets_tables`;\n - `:ets_tables` for `erlang_vm_ets_tables`;\n - `:processes_bytes_total` for `erlang_vm_memory_processes_bytes_total`;\n - `:system_bytes_total` for `erlang_vm_memory_system_bytes_total`.\n\nBy default all metrics are enabled.","ref":"vm-memory-collector.html#configuration"},{"type":"extras","title":"VM Statistics Collector","doc":"/* chrome bug workaround */\n.content-inner li pre{overflow: inherit;}\n \n# VM Statistics Collector\nCollects Erlang VM metrics using\n[:erlang.statistics/1](http://erlang.org/doc/man/erlang.html#statistics-1).","ref":"vm-statistics-collector.html"},{"type":"extras","title":"Exported metrics - VM Statistics Collector","doc":"erlang_vm_statistics_bytes_output_total \n\tType: counter. \n    The total number of bytes output to ports.\n   \n   \n     erlang_vm_statistics_bytes_received_total \n\tType: counter. \n    The total number of bytes received through ports.\n   \n   \n     erlang_vm_statistics_context_switches \n\tType: counter. \n    The total number of context switches since the system started.\n   \n   \n     erlang_vm_statistics_garbage_collection_number_of_gcs \n\tType: counter. \n    The total number of garbage collections since the system started.\n   \n   \n     erlang_vm_statistics_garbage_collection_words_reclaimed \n\tType: counter. \n    The total number of words reclaimed by GC since the system started.\n   \n   \n     erlang_vm_statistics_garbage_collection_bytes_reclaimed \n\tType: counter. \n    The total number of bytes reclaimed by GC since the system started.\n   \n   \n     erlang_vm_statistics_reductions_total \n\tType: counter. \n    Total reductions count.\n   \n   \n     erlang_vm_statistics_run_queues_length_total \n\tType: gauge. \n    The total length of the run-queues. That is, the number of\n    processes and ports that are ready to run on all available run-queues.\n   \n   \n     erlang_vm_statistics_runtime_milliseconds \n\tType: counter. \n    The sum of the runtime for all threads in the Erlang runtime system.\n   \n   \n     erlang_vm_statistics_wallclock_time_milliseconds \n\tType: counter. \n    Can be used in the same manner as\n     erlang_vm_statistics_runtime_milliseconds ,\n\texcept that real time is measured as opposed to runtime or CPU time.","ref":"vm-statistics-collector.html#exported-metrics"},{"type":"extras","title":"Configuration - VM Statistics Collector","doc":"Metrics exported by this collector can be configured via\n`:vm_statistics_collector_metrics` key of `:prometheus` app environment.\n\nOptions are the same as Item parameter values for\n[:erlang.statistics/1](http://erlang.org/doc/man/erlang.html#statistics-1):\n - `:context_switches` for `erlang_vm_statistics_context_switches`;\n - `:garbage_collection`\n   for `erlang_vm_statistics_garbage_collection_number_of_gcs`,\n   `:erlang_vm_statistics_garbage_collection_bytes_reclaimed`, and\n   `:erlang_vm_statistics_garbage_collection_words_reclaimed`;\n - `:io` for `erlang_vm_statistics_bytes_output_total` and\n    `erlang_vm_statistics_bytes_received_total`;\n - `:reductions` for `erlang_vm_statistics_reductions_total`;\n - `:run_queue` for `erlang_vm_statistics_run_queues_length_total`;\n - `:runtime` for `erlang_vm_statistics_runtime_milliseconds`;\n - `:wall_clock` for `erlang_vm_statistics_wallclock_time_milliseconds`.\n\nBy default all metrics are enabled.","ref":"vm-statistics-collector.html#configuration"},{"type":"extras","title":"VM System Info Collector","doc":"/* chrome bug workaround */\n.content-inner li pre{overflow: inherit;}\n \n# VM System Information Collector\nCollects Erlang VM metrics using\n[:erlang.system_info/1](http://erlang.org/doc/man/erlang.html#system_info-1).","ref":"vm-system-info-collector.html"},{"type":"extras","title":"Exported metrics - VM System Info Collector","doc":"erlang_vm_ets_limit \n\tType: gauge. \n    The maximum number of ETS tables allowed.\n   \n   \n     erlang_vm_logical_processors \n\tType: gauge. \n    The detected number of logical processors configured in the system.\n   \n   \n     erlang_vm_logical_processors_available \n\tType: gauge. \n    The detected number of logical processors\n    available to the Erlang runtime system.\n   \n   \n     erlang_vm_logical_processors_online \n\tType: gauge. \n    The detected number of logical processors online on the system.\n   \n   \n     erlang_vm_port_count \n\tType: gauge. \n    The number of ports currently existing at the local node.\n   \n   \n     erlang_vm_port_limit \n\tType: gauge. \n    The maximum number of simultaneously existing ports at the local node.\n   \n   \n     erlang_vm_process_count \n\tType: gauge. \n    The number of processes currently existing at the local node.\n   \n   \n     erlang_vm_process_limit \n\tType: gauge. \n    The maximum number of simultaneously existing processes\n    at the local node.\n   \n   \n     erlang_vm_schedulers \n\tType: gauge. \n    The number of scheduler threads used by the emulator.\n   \n   \n     erlang_vm_schedulers_online \n\tType: gauge. \n    The number of schedulers online.\n   \n   \n     erlang_vm_smp_support \n\tType: boolean. \n    1 if the emulator has been compiled with SMP support, otherwise 0.\n   \n   \n     erlang_vm_threads \n\tType: boolean. \n    1 if the emulator has been compiled with thread support, otherwise 0.\n   \n   \n     erlang_vm_thread_pool_size \n\tType: gauge. \n    The number of async threads in the async thread pool\n    used for asynchronous driver calls.\n   \n   \n     erlang_vm_time_correction \n\tType: boolean. \n    1 if time correction is enabled, otherwise 0.","ref":"vm-system-info-collector.html#exported-metrics"},{"type":"extras","title":"Configuration - VM System Info Collector","doc":"Metrics exported by this collector can be configured via\n`:vm_system_info_collector_metrics` key of `:prometheus` app environment.\n\nOptions are the same as Item parameter values for\n[:erlang.system_info/1](http://erlang.org/doc/man/erlang.html#system_info-1):\n - `:ets_limit` for `erlang_vm_ets_limit`;\n - `:logical_processors` for `erlang_vm_logical_processors`;\n - `:logical_processors_available` for\n    `erlang_vm_logical_processors_available`;\n - `:logical_processors_online` for `erlang_vm_logical_processors_online`;\n - `:port_count` for `erlang_vm_port_count`;\n - `:port_limit` for `erlang_vm_port_limit`;\n - `:process_count` for `erlang_vm_process_count`;\n - `:process_limit` for `erlang_vm_process_limit`;\n - `:schedulers` for `erlang_vm_schedulers`;\n - `:schedulers_online` for `erlang_vm_schedulers_online`;\n - `:smp_support` for `erlang_vm_smp_support`;\n - `:threads` for `erlang_threads`;\n - `:thread_pool_size` for `erlang_vm_thread_pool_size`;\n - `:time_correction` for `erlang_vm_time_correction`.\nBy default all metrics are enabled.","ref":"vm-system-info-collector.html#configuration"},{"type":"extras","title":"Time","doc":"Measuring time intervals is trivial - you just have to be sure you are using\nmonotonic time source. Basically interval is a difference between\nstart time and end time.\nErlang has standard `erlang:monotonic_time` function that returns\nso called native time units. Native time units are meaningless\nand have to be converted to seconds (or other units)\nusing `erlang:convert_time_unit`.\nHowever as `erlang:convert_time_unit` documentation\n[warns](http://erlang.org/doc/man/erlang.html#convert_time_unit-3):\n\n```\nYou may lose accuracy and precision when converting between  time units.\nIn order to minimize such loss, collect all data at native time unit and\ndo the conversion on the end result.\n```\n\nand because Prometheus mandates support for floats,\n`set_duration/observe_duration` functions always work with\nnative time units and conversion is delayed until scraping/retrieving value.\nTo implement this, metric needs to know desired time unit.\nUsers can specify time unit explicitly via `duration_unit`\nor implicitly via metric name (preferred, since prometheus best practices\nguide insists on ` _duration_ ` metric name format).\n\nPossible units:\n - :microseconds;\n - :milliseconds;\n - :seconds;\n - :minutes;\n - :hours;\n - :days.\n\nHistogram also converts buckets bounds to native units if\nduration_unit is provided. It converts it back when scraping or\nretrieving value.\n\nIf values already converted to a \"real\" unit, conversion can be disabled\nby setting `:duration_unit` to `false`.","ref":"time.html"},{"type":"extras","title":"Examples - Time","doc":"Example where duration unit derived from name:\n```\nHistogram.new([name: :fun_duration_seconds,\n               buckets: [0.5, 1.1], # in seconds\n               help: \"\"])\n\nHistogram.observe_duration(:fun_duration_seconds, do: Process.sleep(1000))\n\nHistogram.value(:fun_duration_seconds)\n{[0, 1, 0], 1.001039204}\n```\n\nExample where duration unit set explicitly:\n```\nHistogram.new([name: :fun_duration_histogram,\n               buckets: [500, 1100], # in milliseconds\n               duration_unit: :milliseconds,\n               help: \"\"])\n\nHistogram.observe_duration(:fun_duration_histogram, do: Process.sleep(1000))\n\nHistogram.value(:fun_duration_histogram)\n{[0, 1, 0], 1000.714918}\n```\n\nExample where value is in seconds already:\n```\nHistogram.new([name: :duration_seconds,\n               buckets: [0.5, 1.1], # in seconds\n               duration_unit: false,\n               help: \"\"])\n\nHistogram.dobserve(:duration_seconds, 1.2)\n\nHistogram.value(:duration_seconds)\n{[0, 0, 1], 1.2}\n```","ref":"time.html#examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}